package com.ruoyi.tuya.mapper;

import java.util.List;
import com.ruoyi.tuya.domain.SysUsers;

/**
 * 平台用户Mapper接口
 * 
 * @author ruoyi
 * @date 2022-07-19
 */
public interface SysUsersMapper 
{
    /**
     * 查询平台用户
     * 
     * @param id 平台用户主键
     * @return 平台用户
     */
    public SysUsers selectSysUsersById(Long id);

    /**
     * 查询平台用户列表
     * 
     * @param sysUsers 平台用户
     * @return 平台用户集合
     */
    public List<SysUsers> selectSysUsersList(SysUsers sysUsers);

    /**
     * 新增平台用户
     * 
     * @param sysUsers 平台用户
     * @return 结果
     */
    public int insertSysUsers(SysUsers sysUsers);

    /**
     * 修改平台用户
     * 
     * @param sysUsers 平台用户
     * @return 结果
     */
    public int updateSysUsers(SysUsers sysUsers);

    /**
     * 删除平台用户
     * 
     * @param id 平台用户主键
     * @return 结果
     */
    public int deleteSysUsersById(Long id);

    /**
     * 批量删除平台用户
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteSysUsersByIds(Long[] ids);
}
